@@ -157,7 +157,7 @@ namespace AST {
                      exp_ptr args, const yy::location& argsLoc,  
                      mod_ptr mods)
     : ASTreplacement(std::move(mods), nameLoc + argsLoc, empty), mLoopArgs(std::move(args)),
-      mLoopModHolder(nullptr), mLoopIndexName(nameIndex), mLoopName(name)
+        mLoopModHolder(nullptr), mLoopData{0.0}, mLoopIndexName(nameIndex), mLoopName(name)
     {
         mLoopBody.addLoopParameter(mLoopIndexName, mLocation);
         mFinallyBody.addLoopParameter(mLoopIndexName, mLocation);
@@ -218,8 +218,8 @@ namespace AST {
     ASTswitch::unify()
     {
         if (mElseBody.mPathOp != mPathOp) mPathOp = unknownPathop;
-        for (auto&& _case: mCases)
-            if (_case.second->mPathOp != mPathOp)
+        for (auto& [caseValue, caseBody]: mCases)
+            if (caseBody->mPathOp != mPathOp)
                 mPathOp = unknownPathop;
     }
 
@@ -282,7 +282,6 @@ namespace AST {
     }
     
     ASTcompiledPath::ASTcompiledPath()
-    : mCached(false), mUseTerminal(false), mParameters(nullptr)
     {
         mPathUID = NextPathUID();
     }
@@ -302,8 +301,8 @@ namespace AST {
     ASTpathCommand::ASTpathCommand(const std::string& s, mod_ptr mods, 
                                    exp_ptr params, const yy::location& loc)
     :   ASTreplacement(std::move(mods), loc, command),
-        mMiterLimit(4.0), mStrokeWidth(0.1), mParameters(std::move(params)),
-        mFlags(CF_MITER_JOIN + CF_BUTT_CAP)
+        mMiterLimit(DefaultMiterLimit), mStrokeWidth(DefaultStrokeWidth), 
+        mParameters(std::move(params)), mFlags(CF_MITER_JOIN + CF_BUTT_CAP)
     {
         if (s == "FILL")
             mFlags |= CF_FILL;
@@ -477,7 +476,7 @@ namespace AST {
         caseRange cr{i, i};
         
         switchMap::const_iterator it = mCaseMap.find(cr);
-        if (it != mCaseMap.end()) (*it).second->traverse(parent, tr, r);
+        if (it != mCaseMap.cend()) (*it).second->traverse(parent, tr, r);
         else mElseBody.traverse(parent, tr, r);
     }
     
@@ -537,7 +536,7 @@ namespace AST {
     {
         if (r->mCurrentPath->mCached)
             return;
-        double opData[7];
+        pathOpData opData;
         pathData(opData, r);
         r->mCurrentPath->addPathOp(this, opData, s, tr, r);
     }
@@ -758,11 +757,11 @@ namespace AST {
                                 mLoopData[1] == floor(mLoopData[1]) &&
                                 mLoopData[2] == floor(mLoopData[2]) &&
                                 mLoopData[0] >= 0.0 && mLoopData[1] >= 0.0 &&
-                                mLoopData[0] < 9007199254740992. &&
-                                mLoopData[1] < 9007199254740992.;
+                                mLoopData[0] < MaxNatural &&
+                                mLoopData[1] < MaxNatural;
                     finallyNatural = finallyNatural && bodyNatural &&
                                 mLoopData[1] + mLoopData[2] >= -1.0 &&
-                                mLoopData[1] + mLoopData[2] < 9007199254740992.;
+                                mLoopData[1] + mLoopData[2] < MaxNatural;
                     mLoopArgs.reset();
                     mLoopBody.mParameters.front().isNatural = bodyNatural;
                     mFinallyBody.mParameters.front().isNatural = finallyNatural;
@@ -835,9 +834,9 @@ namespace AST {
     {
         ASTreplacement::compile(ph, b);
         Compile(mSwitchExp, ph, b);
-        for (auto&& _case: mCases) {
-            Compile(_case.first, ph, b);
-            _case.second->compile(ph, b);
+        for (auto& [caseValue, caseBody] : mCases) {
+            Compile(caseValue, ph, b);
+            caseBody->compile(ph, b);
         }
         mElseBody.compile(ph, b);
         
@@ -853,13 +852,13 @@ namespace AST {
                 
                 // Build the switch map from the stored case value expressions
                 double val[2] = { 0.0 };
-                for (auto&& _case: mCases) {
-                    const ASTexpression* valExp = _case.first.get();
+                for (auto& [caseValue, caseBody] : mCases) {
+                    const ASTexpression* valExp = caseValue.get();
                     if (!valExp) {
                         CfdgError::Error(mLocation, "Case value missing", b);
                         return;
                     }
-                    ASTrepContainer* body = _case.second.get();
+                    ASTrepContainer* body = caseBody.get();
                     for (auto&& term: *valExp) {
                         const ASTfunction* func = dynamic_cast<const ASTfunction*>(&term);
                         caseType high = 0, low = 0;
@@ -1082,12 +1081,13 @@ namespace AST {
             }
         };
         std::vector<tempcase> tempCases;
-        for (auto&& caseinfo: mCases)
-            tempCases.emplace_back(caseinfo.second.get());
-        for (auto&& caseinfo: mCaseMap) {
+        for (auto& [caseValue, caseContent] : mCases)
+            tempCases.emplace_back(caseContent.get());
+        for (const auto& [caseRange, caseBody]: mCaseMap) {
             for (auto&& tempcaseinfo: tempCases)
-                if (caseinfo.second == tempcaseinfo.mCaseBody) {
-                    for (auto i = caseinfo.first.first; i <= caseinfo.first.second; ++i)
+                if (caseBody == tempcaseinfo.mCaseBody) {
+                    auto [caseRangeStart, caseRangeEnd] = caseRange;
+                    for (auto i = caseRangeStart; i <= caseRangeEnd; ++i)
                         tempcaseinfo.mCases.push_back(i);
                     break;
                 }
@@ -1238,8 +1238,9 @@ namespace AST {
     
     static exp_ptr GetFlagsAndStroke(ASTtermArray& terms, int& flags, Builder* b)
     {
-        ASTtermArray temp(std::move(terms));
         exp_ptr ret;
+        ASTtermArray temp;
+        temp.swap(terms);
         
         for (term_ptr& term: temp) {
             switch (term->modType) {
@@ -1352,7 +1353,7 @@ namespace AST {
     }
     
     void
-    ASTcompiledPath::addPathOp(const ASTpathOp* pop, double data[6], const Shape& s, 
+    ASTcompiledPath::addPathOp(const ASTpathOp* pop, ASTpathOp::pathOpData& data, const Shape& s,
                                bool tr, RendererAST* r)
     {
         // Process the parameters for ARCTO/ARCREL
@@ -1376,9 +1377,9 @@ namespace AST {
                 sweep = !sweep;
             }
         } else if (tr) {
-            s.mWorldState.m_transform.transform(data + 0, data + 1);
-            s.mWorldState.m_transform.transform(data + 2, data + 3);
-            s.mWorldState.m_transform.transform(data + 4, data + 5);
+            s.mWorldState.m_transform.transform(&data[0], &data[1]);
+            s.mWorldState.m_transform.transform(&data[2], &data[3]);
+            s.mWorldState.m_transform.transform(&data[4], &data[5]);
         }
         
         // If this is the first path operation following a path command then set the 
@@ -1440,23 +1441,23 @@ namespace AST {
         
         switch (pop->mPathOp) {
             case MOVEREL:
-                mPath.rel_to_abs(data + 0, data + 1);
+                mPath.rel_to_abs(&data[0], &data[1]);
 		FALLTHROUGH;
             case MOVETO:
                 mPath.move_to(data[0], data[1]);
                 r->mWantMoveTo = false;
                 break;
             case LINEREL:
-                mPath.rel_to_abs(data + 0, data + 1);
+                mPath.rel_to_abs(&data[0], &data[1]);
 		FALLTHROUGH;
             case LINETO:
                 mPath.line_to(data[0], data[1]);
                 break;
             case ARCREL:
-                mPath.rel_to_abs(data + 0, data + 1);
+                mPath.rel_to_abs(&data[0], &data[1]);
 		FALLTHROUGH;
             case ARCTO: {
-                if (!agg::is_vertex(mPath.last_vertex(data + 2, data + 3)) ||
+                if (!agg::is_vertex(mPath.last_vertex(&data[2], &data[3])) ||
                     (tr && s.mWorldState.m_transform.determinant() < 1e-10))
                 {
                     break;
@@ -1480,13 +1481,13 @@ namespace AST {
                 break;
             }
             case CURVEREL:
-                mPath.rel_to_abs(data + 0, data + 1);
-                mPath.rel_to_abs(data + 2, data + 3);
-                mPath.rel_to_abs(data + 4, data + 5);
+                mPath.rel_to_abs(&data[0], &data[1]);
+                mPath.rel_to_abs(&data[2], &data[3]);
+                mPath.rel_to_abs(&data[4], &data[5]);
 		FALLTHROUGH;
             case CURVETO:
                 if ((pop->mFlags & CF_CONTINUOUS) &&
-                    !agg::is_curve(mPath.last_vertex(data + 4, data + 5)))
+                    !agg::is_curve(mPath.last_vertex(&data[4], &data[5])))
                 {
                     CfdgError::Error(pop->mLocation, "Smooth curve operations must be preceded by another curve operation.");
                     break;
@@ -1554,13 +1555,13 @@ namespace AST {
     }
     
     void
-    ASTpathOp::pathData(double* data, RendererAST* rti) const
+    ASTpathOp::pathData(pathOpData& data, RendererAST* rti) const
     {
         if (mArguments) {
-            if (mArguments->evaluate(data, 7, rti) < 0)
+            if (mArguments->evaluate(data.data(), 6, rti) < 0)
                 CfdgError::Error(mArguments->where, "Cannot evaluate arguments");
         } else {
-            mChildChange.modData.m_transform.store_to(data);
+            mChildChange.modData.m_transform.store_to(data.data());
         }
     }
     
@@ -1568,11 +1569,11 @@ namespace AST {
     ASTpathOp::pathDataConst(Builder* b)
     {
         if (mArguments && mArguments->isConstant) {
-            double data[7];
-            if (mArguments->evaluate(data, 7) < 0)
+            pathOpData data;
+            if (mArguments->evaluate(data.data(), 6) < 0)
                 CfdgError::Error(mArguments->where, "Cannot evaluate arguments", b);
             mArguments.reset();
-            mChildChange.modData.m_transform.load_from(data);
+            mChildChange.modData.m_transform.load_from(data.data());
         }
     }
 
@@ -1589,10 +1590,10 @@ namespace AST {
                         if (flag)
                             CfdgError::Error(flag->where, "There can only be one flag argument", b);
                         flag = &arg;
-                        if (const ASTreal* rf = dynamic_cast<const ASTreal*> (&arg))
-                            mFlags |= rf ? static_cast<int>(rf->value) : 0;
-                        else
+                        double rFlag = 0;
+                        if (!arg.isConstant || arg.evaluate(&rFlag, 1) != 1)
                             CfdgError::Error(arg.where, "Flag expressions must be constant", b);
+                        mFlags |= static_cast<int>(rFlag);
                         --mArgCount;    // don't count flags
                         break;
                     }
@@ -1614,17 +1615,23 @@ namespace AST {
             case LINEREL:
             case MOVETO:
             case MOVEREL:
+                if (mFlags)
+                    CfdgError::Error(mLocation, "No flags can be used with this operation", b);
                 if (mArgCount != 2)
                     CfdgError::Error(mLocation, "Move/line path operation requires two arguments", b);
                 break;
             case ARCTO:
             case ARCREL:
+                if (mFlags & ~(CF_ARC_CW | CF_ARC_LARGE))
+                    CfdgError::Error(mLocation, "Only CF::ArcCW and CF::ArcLarge flags can be used with this operation", b);
                 if (mArgCount != 3 && mArgCount != 5)
                     CfdgError::Error(mLocation, "Arc path operations require three or five arguments", b);
                 break;
             case CURVETO:
             case CURVEREL:
-                if (mFlags & CF_CONTINUOUS) {
+                if (mFlags & ~CF_CONTINUOUS) {
+                    CfdgError::Error(mLocation, "Only CF::Continuous flag can be used with this operation", b);
+                } else if (mFlags & CF_CONTINUOUS) {
                     if (mArgCount != 2 && mArgCount != 4)
                         CfdgError::Error(mLocation, "Continuous curve path operations require two or four arguments", b);
                 } else {
@@ -1633,6 +1640,8 @@ namespace AST {
                 }
                 break;
             case CLOSEPOLY:
+                if (mFlags & ~CF_ALIGN)
+                    CfdgError::Error(mLocation, "Only CF::Align flag can be used with this operation", b);
                 if (mArgCount)
                     CfdgError::Error(mLocation, "CLOSEPOLY takes no arguments, only flags", b);
                 break;
