@@ -32,7 +32,7 @@
 
 #include <iosfwd>
 #include <string>
-#include <time.h>
+#include <ctime>
 #include <vector>
 #include "agg2/agg_trans_affine.h"
 #include "agg2/agg_color_rgba.h"
@@ -46,6 +46,9 @@
 #include <memory>
 #include <cstdint>
 #include <cstddef>
+#include <array>
+#include <map>
+#include <atomic>
 
 #define _unused(x) ((void)(x))
 
@@ -62,12 +65,11 @@ class Builder;
 
 class DeferUntilRuntime : public std::exception {
 public:
-    virtual const char* what() const noexcept;
+    const char* what() const noexcept override;
 };
 class CfdgError : public std::exception {
 public:
-    virtual const char* what() const noexcept;
-    CfdgError& operator=(const CfdgError& e) noexcept;
+    const char* what() const noexcept override;
     yy::location    where;
     static yy::location Default;
     
@@ -107,7 +109,7 @@ class AbstractSystem {
         using istr_ptr = std::unique_ptr<std::istream>;
         using ostr_ptr = std::unique_ptr<std::ostream>;
     
-        int cfdgVersion = 2;
+        int cfdgVersion = 3;
         bool mFirstCfdgRead = true;
 
         virtual void message(const char* fmt, ...) = 0;
@@ -116,7 +118,7 @@ class AbstractSystem {
         virtual void catastrophicError(const char* what) = 0;
         virtual bool isGuiProgram() { return true; }
     
-        virtual istr_ptr openFileForRead(const std::string& path) = 0;
+        virtual istr_ptr openFileForRead(const std::string& path);
         virtual istr_ptr tempFileForRead(const FileString& path);
         virtual ostr_ptr tempFileForWrite(TempType tt, FileString& nameOut) = 0;
         virtual const FileChar* tempFileDirectory() = 0;
@@ -131,25 +133,21 @@ class AbstractSystem {
         virtual std::wstring normalize(const std::string&) = 0;
         
         struct Stats {
-            int     shapeCount;     // finished shapes in image
-            int     toDoCount;      // unfinished shapes still to expand
+            int     shapeCount = 0;     // finished shapes in image
+            int     toDoCount = 0;      // unfinished shapes still to expand
             
-            bool    inOutput;       // true if we are in the output loop
-            bool    fullOutput;     // not an incremental output
-            bool    finalOutput;    // the last output
-            bool    showProgress;
-            int     outputCount;    // number to be output
-            int     outputDone;     // number output so far
-            clock_t outputTime;
+            bool    inOutput = false;       // true if we are in the output loop
+            bool    fullOutput = false;     // not an incremental output
+            bool    finalOutput = false;    // the last output
+            bool    showProgress = false;
+            int     outputCount = 0;    // number to be output
+            int     outputDone = 0;     // number output so far
+            std::clock_t outputTime = 0;
 
-            bool    animating;      // inside the animation loop
-            AbstractSystem* mSystem;
+            bool    animating = false;      // inside the animation loop
+            AbstractSystem* mSystem = nullptr;
 
-            Stats()
-                : shapeCount(0), toDoCount(0), inOutput(false),
-                  fullOutput(false), finalOutput(false), showProgress(false),
-                  outputCount(0), outputDone(0), outputTime(0), animating(false),
-                  mSystem(nullptr) {}
+            Stats() = default;
             ~Stats()
             {
                 // Cancel system progress bar if it is being displayed
@@ -165,9 +163,10 @@ class AbstractSystem {
         virtual void stats(const Stats&);
         
         virtual ~AbstractSystem();
-    protected:
-        static const FileChar* TempPrefixes[NumberofTempTypes];
-        static const FileChar* TempSuffixes[NumberofTempTypes];
+        static const std::map<std::string, std::pair<const char*, const char*>> ExamplesMap;
+protected:
+        static const std::array<const FileChar*, NumberofTempTypes> TempPrefixes;
+        static const std::array<const FileChar*, NumberofTempTypes> TempSuffixes;
         static const FileChar* TempPrefixAll;
         virtual void clearAndCR() {};
 };
@@ -188,7 +187,7 @@ class Canvas {
         
         int mWidth;
         int mHeight;
-        clock_t mTime;
+        std::clock_t mTime = (std::clock_t)(-1);
         bool mError;
         std::string mFileName;
 };
@@ -212,12 +211,12 @@ class CFDG {
             ) = 0;
             // caller must delete returned object
 
-        bool usesColor;
-        bool usesAlpha;
-        bool uses16bitColor;
-        bool usesBlendMode;
-        bool usesTime;
-        bool usesFrameTime;
+        bool usesColor = false;
+        bool usesAlpha = false;
+        bool uses16bitColor = false;
+        bool usesBlendMode = false;
+        bool usesTime = false;
+        bool usesFrameTime = false;
         static const CfgArray<std::string>  ParamNames;
         static CFG lookupCfg(const std::string& name);
         static const std::string& getCfgName(int c);
@@ -225,16 +224,14 @@ class CFDG {
         static const AST::ASTparameters* ShapeToParams(int shape);
         virtual bool isTiled(agg::trans_affine* tr = nullptr, double* x = nullptr, double* y = nullptr) const = 0;
         virtual frieze_t isFrieze(agg::trans_affine* tr = nullptr, double* x = nullptr, double* y = nullptr) const = 0;
+        virtual bool isTiledOrFrieze() const = 0;
         virtual bool isSized(double* x = nullptr, double* y = nullptr) const = 0;
         virtual bool isTimed(agg::trans_affine_time* t = nullptr) const = 0;
         virtual const agg::rgba& getBackgroundColor() = 0;
         virtual void serialize(std::ostream&) = 0;
 
     protected:
-        CFDG()
-        : usesColor(false), usesAlpha(false), uses16bitColor(false), 
-          usesBlendMode(false), usesTime(false), usesFrameTime(false)
-        { }
+        CFDG() = default;
 };
 
 
@@ -251,9 +248,9 @@ class Renderer {
         virtual void draw(Canvas* canvas) = 0;
         virtual void animate(Canvas* canvas, int frames, int frame, bool zoom) = 0;
 
-        volatile bool requestStop;     // stop ASAP
-        volatile bool requestFinishUp; // stop expanding, and do final output
-        volatile bool requestUpdate;   // call stats() soon
+        std::atomic_bool requestStop;     // stop ASAP
+        std::atomic_bool requestFinishUp; // stop expanding, and do final output
+        std::atomic_bool requestUpdate;   // call stats() soon
         
         int m_width;
         int m_height;
