@@ -39,23 +39,9 @@
 
 #include "bounds.h"
 #include "prettyint.h"
-#include <streambuf>
 #include <istream>
 #include "builder.h"
 
-struct membuf: std::streambuf {
-    membuf(char const* base, std::size_t size) {
-        char* p(const_cast<char*>(base));
-        this->setg(p, p, p + size);
-    }
-};
-struct imemstream: virtual membuf, std::istream {
-    imemstream(char const* base, std::size_t size)
-    : membuf(base, size)
-    , std::istream(static_cast<std::streambuf*>(this)) {
-    }
-};
-
 using std::cin;
 using std::cerr;
 using std::endl;
@@ -115,33 +101,10 @@ CommandLineSystem::openFileForRead(const std::string& path)
             mInputBuffer = std::make_unique<std::string>(ss.str());
         }
         mFirstCfdgRead = false;
-        return std::make_unique<imemstream>(mInputBuffer->data(), mInputBuffer->length());
+        return std::make_unique<std::istringstream>(*mInputBuffer);
     }
-    
-    if (!mFirstCfdgRead) {
-        char dirchar =
-#ifdef _WIN32
-            '\\';
-#else
-            '/';
-#endif
-        auto dirloc = path.rfind(dirchar);
-        auto exfile = path.substr(dirloc == std::string::npos ? 0 : dirloc + 1);
-    
-        auto example = ExamplesMap.find(exfile);
-        if (example != ExamplesMap.end()) {
-            auto cfdg = cfdgVersion == 2 ? example->second.second : example->second.first;
-            return std::make_unique<imemstream>(cfdg, std::strlen(cfdg));
-        }
-    } else {
-        mFirstCfdgRead = false;
-    }
-    
-    istr_ptr f = std::make_unique<std::ifstream>(path.c_str(), std::ios::binary);
-    if (f && !f->good())
-        f.reset();
 
-    return f;
+    return AbstractSystem::openFileForRead(path);
 }
 
 void
@@ -151,8 +114,8 @@ CommandLineSystem::stats(const Stats& s)
     
     if (s.inOutput || s.showProgress) {
         double v = s.outputCount ? static_cast<double>(s.outputDone) / s.outputCount : 1.0;
-        static const char prog[] = "**************************************************";
-        static const char todo[] = "..................................................";
+        static const char *prog = "**************************************************";
+        static const char *todo = "..................................................";
         if (v < 0.0) v = 0.0;
         if (v > 1.0 || !std::isfinite(v)) v = 1.0;
         int progress = static_cast<int>(v * 50.0 + 0.5);
@@ -172,4 +135,3 @@ CommandLineSystem::stats(const Stats& s)
     cerr.flush();
 }
 
-#include "examples.h"
