@@ -33,7 +33,6 @@
 #include <iosfwd>
 #include <string>
 #include <memory>
-#include <map>
 #include <utility>
 #include <vector>
 
@@ -50,14 +49,13 @@ class CommandLineSystem : public PosixSystem
 #endif
 {
 protected:
-    bool mQuiet;
-    bool mNeedEndl;
-    bool mErrorMode;
+    bool mQuiet = false;
+    bool mNeedEndl = false;
+    bool mErrorMode = false;
     std::unique_ptr<std::string> mInputBuffer;
     virtual const char* maybeLF();
 public:
-    CommandLineSystem(bool q = false) : mQuiet(q), mNeedEndl(false),
-        mErrorMode(false) { };
+    CommandLineSystem(bool q = false) : mQuiet(q) { };
     ~CommandLineSystem() override = default;
     void message(const char* fmt, ...) override;
     void syntaxError(const CfdgError& err) override;
@@ -69,7 +67,6 @@ public:
     void stats(const Stats&) override;
     void orphan() override {};
 private:
-    static const std::map<std::string, std::pair<const char*, const char*>> ExamplesMap;
     std::vector<char> buf;
 };
 
